==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebComboChangeEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComboChangeEventArgsDetailDescription } from "./WebComboChangeEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebComboChangeEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebComboChangeEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebComboChangeEventArgsDetailDescriptionMetadata.a == null) {
                WebComboChangeEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebComboChangeEventArgsDetailDescriptionMetadata.c(WebComboChangeEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebComboChangeEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebComboChangeEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ComboChangeEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("NewValueRef", "(w:NewValue,wf:NewValue)DataRef:object");
            a.item("ItemsRef", "(w:Items,wf:Items)DataRef:object");
            a.item("ChangeType", "(wc:Type)ExportedType:string:ComboChangeType");
            a.item("ChangeType@stringUnion", "WebComponents;React");
            a.item("ChangeType@names", "Selection;Deselection;Addition");
        }
        static d(a) {
            WebComboChangeEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebComboChangeEventArgsDetail", () => new WebComboChangeEventArgsDetailDescription());
            a.ac("WebComboChangeEventArgsDetail", WebComboChangeEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebComboChangeEventArgsDetailDescriptionMetadata.$t = markType(WebComboChangeEventArgsDetailDescriptionMetadata, 'WebComboChangeEventArgsDetailDescriptionMetadata');
    WebComboChangeEventArgsDetailDescriptionMetadata.a = null;
    return WebComboChangeEventArgsDetailDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebComboChangeEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComboChangeEventArgsDetailDescription } from "./WebComboChangeEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebComboChangeEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebComboChangeEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebComboChangeEventArgsDetailDescriptionMetadata.a == null) {
                WebComboChangeEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebComboChangeEventArgsDetailDescriptionMetadata.c(WebComboChangeEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebComboChangeEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebComboChangeEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ComboChangeEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("NewValueRef", "(w:NewValue,wf:NewValue)DataRef:object");
            a.item("ItemsRef", "(w:Items,wf:Items)DataRef:object");
            a.item("ChangeType", "(wc:Type)ExportedType:string:ComboChangeType");
            a.item("ChangeType@stringUnion", "WebComponents;React");
            a.item("ChangeType@names", "Selection;Deselection;Addition");
        }
        static d(a) {
            WebComboChangeEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebComboChangeEventArgsDetail", () => new WebComboChangeEventArgsDetailDescription());
            a.ad("WebComboChangeEventArgsDetail", WebComboChangeEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebComboChangeEventArgsDetailDescriptionMetadata.$t = markType(WebComboChangeEventArgsDetailDescriptionMetadata, 'WebComboChangeEventArgsDetailDescriptionMetadata');
    WebComboChangeEventArgsDetailDescriptionMetadata.a = null;
    return WebComboChangeEventArgsDetailDescriptionMetadata;
})();
